==> openjdk-17_17.0.11+9.orig.tar.xz: openjdk-17-17.0.11+9/test/langtools/jdk/javadoc/doclet/testVersionOption/TestVersionOption.java <==
/*
 * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug      8177048
 * @summary  javadoc should support --version and --full-version flags
 * @library ../../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build    javadoc.tester.* TestVersionOption
 * @run main TestVersionOption
 */

import javadoc.tester.JavadocTester;

public class TestVersionOption extends JavadocTester {

    public static void main(String... args) throws Exception {
        TestVersionOption tester = new TestVersionOption();
        tester.runTests();
    }

    @Test
    public void testFullVersionOption() {
        javadoc("--full-version");
        checkExit(Exit.OK);

        checkOutput(Output.OUT, true, "javadoc full version \"" + System.getProperty("java.runtime.version") + "\"");
    }


    @Test
    public void testVersionOption() {
        javadoc("--version");
        checkExit(Exit.OK);

        checkOutput(Output.OUT, true, "javadoc " + System.getProperty("java.version"));
    }

}

==> openjdk-21_21.0.10+7.orig.tar.xz: openjdk-21-21.0.10+7/test/langtools/jdk/javadoc/doclet/testVersionOption/TestVersionOption.java <==
/*
 * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug      8177048
 * @summary  javadoc should support --version and --full-version flags
 * @library ../../lib
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build    javadoc.tester.* TestVersionOption
 * @run main TestVersionOption
 */

import javadoc.tester.JavadocTester;

public class TestVersionOption extends JavadocTester {

    public static void main(String... args) throws Exception {
        var tester = new TestVersionOption();
        tester.runTests();
    }

    @Test
    public void testFullVersionOption() {
        javadoc("--full-version");
        checkExit(Exit.OK);

        checkOutput(Output.OUT, true, "javadoc full version \"" + System.getProperty("java.runtime.version") + "\"");
    }


    @Test
    public void testVersionOption() {
        javadoc("--version");
        checkExit(Exit.OK);

        checkOutput(Output.OUT, true, "javadoc " + System.getProperty("java.version"));
    }

}
